videocollection/videocollectionwrapper/inc/videothumbnaildata_p.h
changeset 20 b9e04db066d4
parent 15 cf5481c2bc0b
child 24 7d93ee07fb27
--- a/videocollection/videocollectionwrapper/inc/videothumbnaildata_p.h	Mon May 03 12:32:50 2010 +0300
+++ b/videocollection/videocollectionwrapper/inc/videothumbnaildata_p.h	Fri May 14 15:53:50 2010 +0300
@@ -19,12 +19,13 @@
 #define __VIDEOTHUMBNAILDATAPRIVATE_H__
 
 // INCLUDES
-#include <QObject>
-#include <QPointer>
-#include <QCache>
-#include <QIcon>
-#include <QSet>
-#include <QList>
+#include <qobject.h>
+#include <qpointer.h>
+#include <qcache.h>
+#include <qicon.h>
+#include <qset.h>
+#include <qlist.h>
+#include <qhash.h>
 #include <e32const.h>
 #include <mpxitemid.h>
 
@@ -201,11 +202,11 @@
      * for some item. Thumbnail data is saved to icon cache.
      *
      * @param tnData: thumbnail
      * @param internal: internal data contains pointer to the media id used in emitted signal
      * @param error: possible error code from thumbnail manager ( 0 == ok )
      *
      */
-    void thumbnailReadySlot(QPixmap tnData, void *internal, int error);
+    void thumbnailReadySlot(QPixmap tnData, const TMPXItemId &mediaId, int error);
 
     /**
      * VideoListDataModel signals this slot when the model has been changed.
@@ -201,11 +202,11 @@
      *
      * @param tnData: thumbnail
-     * @param internal: internal data contains pointer to the media id used in emitted signal
+     * @param mediaId: pointer to the media id used in emitted signal
      * @param error: possible error code from thumbnail manager ( 0 == ok )
      *